# python-exoscale: Python bindings for Exoscale API

This library allows developpers to use the [Exoscale] cloud platform API with
high-level Python bindings. API documentation and usage examples can be found
at this address: https://exoscale.github.io/python-exoscale

[exoscale]: https://www.exoscale.com/
